package cn.ibizlab.core.uaa.service.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.Map;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Collection;
import java.util.Objects;
import java.util.Optional;
import java.math.BigInteger;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.ObjectUtils;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.context.annotation.Lazy;
import cn.ibizlab.core.uaa.domain.SysAppMenuItem;
import cn.ibizlab.core.uaa.filter.SysAppMenuItemSearchContext;
import cn.ibizlab.core.uaa.service.ISysAppMenuItemService;

import cn.ibizlab.util.helper.CachedBeanCopier;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import cn.ibizlab.core.uaa.mapper.SysAppMenuItemMapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.alibaba.fastjson.JSONObject;
import org.springframework.util.StringUtils;

/**
 * 实体[系统菜单项] 服务对象接口实现
 */
@Slf4j
@Service("SysAppMenuItemServiceImpl")
public class SysAppMenuItemServiceImpl extends ServiceImpl<SysAppMenuItemMapper, SysAppMenuItem> implements ISysAppMenuItemService {


    private int batchSize = 500;

    @Override
    @Transactional
    public boolean save(SysAppMenuItem et) {
        if(!saveOrUpdate(et))
            return false;
        return true;
    }

    @Override
    @Transactional(
            rollbackFor = {Exception.class}
    )
    public boolean saveOrUpdate(SysAppMenuItem et) {
        if (null == et) {
            return false;
        } else {
            return checkKey(et) ? this.update(et) : this.create(et);
        }
    }

    @Override
    public void saveBatch(List<SysAppMenuItem> list) {
        saveOrUpdateBatch(list,batchSize);
    }

    @Override
    @Transactional
    public boolean create(SysAppMenuItem et) {
        if(!this.retBool(this.baseMapper.insert(et)))
            return false;
        CachedBeanCopier.copy(get(et.getAppmenuitemid()),et);
        return true;
    }

    @Override
    public void createBatch(List<SysAppMenuItem> list) {
        this.saveBatch(list,batchSize);
    }

    @Override
    @Transactional
    public boolean update(SysAppMenuItem et) {
        if(!update(et,(Wrapper) et.getUpdateWrapper(true).eq("sys_psappmenuitemid",et.getAppmenuitemid())))
            return false;
        CachedBeanCopier.copy(get(et.getAppmenuitemid()),et);
        return true;
    }

    @Override
    public void updateBatch(List<SysAppMenuItem> list) {
        updateBatchById(list,batchSize);
    }

    @Override
    public SysAppMenuItem getDraft(SysAppMenuItem et) {
        return et;
    }

    @Override
    public boolean checkKey(SysAppMenuItem et) {
        return (!ObjectUtils.isEmpty(et.getAppmenuitemid()))&&(!Objects.isNull(this.getById(et.getAppmenuitemid())));
    }

    @Override
    @Transactional
    public boolean remove(String key) {
        boolean result=removeById(key);
        return result ;
    }

    @Override
    public void removeBatch(Collection<String> idList) {
        removeByIds(idList);
    }

    @Override
    @Transactional
    public SysAppMenuItem get(String key) {
        SysAppMenuItem et = getById(key);
        if(et==null){
            et=new SysAppMenuItem();
            et.setAppmenuitemid(key);
        }
        else{
        }
        return et;
    }



    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<SysAppMenuItem> searchDefault(SysAppMenuItemSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<SysAppMenuItem> pages=baseMapper.searchDefault(context.getPages(),context,context.getSelectCond());
        return new PageImpl<SysAppMenuItem>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }




    @Override
    public List<JSONObject> select(String sql, Map param){
        return this.baseMapper.selectBySQL(sql,param);
    }

    @Override
    @Transactional
    public boolean execute(String sql , Map param){
        if (sql == null || sql.isEmpty()) {
            return false;
        }
        if (sql.toLowerCase().trim().startsWith("insert")) {
            return this.baseMapper.insertBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("update")) {
            return this.baseMapper.updateBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("delete")) {
            return this.baseMapper.deleteBySQL(sql,param);
        }
        log.warn("暂未支持的SQL语法");
        return true;
    }

}


